@@ -29,13 +29,11 @@
 
 #include <QCompleter>
 
-namespace Ui
-{
+namespace Ui {
 class EventOrTodoDesktop;
 }
 
-namespace IncidenceEditorNG
-{
+namespace IncidenceEditorNG {
 class ResourceManagement;
 
 class IncidenceResource : public IncidenceEditor
@@ -45,11 +43,12 @@ public:
     using IncidenceEditorNG::IncidenceEditor::save; // So we don't trigger -Woverloaded-virtual
     using IncidenceEditorNG::IncidenceEditor::load; // So we don't trigger -Woverloaded-virtual
 
-    explicit IncidenceResource(IncidenceAttendee *mIeAttendee, IncidenceDateTime *dateTime, Ui::EventOrTodoDesktop *ui);
+    explicit IncidenceResource(IncidenceAttendee *mIeAttendee, IncidenceDateTime *dateTime,
+                               Ui::EventOrTodoDesktop *ui);
 
-    void load(const KCalCore::Incidence::Ptr &incidence) Q_DECL_OVERRIDE;
-    void save(const KCalCore::Incidence::Ptr &incidence) Q_DECL_OVERRIDE;
-    bool isDirty() const Q_DECL_OVERRIDE;
+    void load(const KCalCore::Incidence::Ptr &incidence) override;
+    void save(const KCalCore::Incidence::Ptr &incidence) override;
+    bool isDirty() const override;
 
     /** resturn the count of resources */
     int resourceCount() const;
@@ -79,7 +78,6 @@ private:
 
     ResourceManagement *resourceDialog;
 };
-
 }
 
 #endif
