@@ -48,9 +48,13 @@ int main(int argc, char **argv)
     parser.addVersionOption();
     parser.addOption(QCommandLineOption(QStringLiteral("new-event"), i18n("Creates a new event")));
     parser.addOption(QCommandLineOption(QStringLiteral("new-todo"), i18n("Creates a new todo")));
-    parser.addOption(QCommandLineOption(QStringLiteral("new-journal"), i18n("Creates a new journal")));
-    parser.addOption(QCommandLineOption(QStringLiteral("item"), i18n("Loads an existing item, or returns without doing anything "
-                                        "when the item is not an event or todo."), QStringLiteral("id")));
+    parser.addOption(QCommandLineOption(QStringLiteral("new-journal"), i18n(
+                                            "Creates a new journal")));
+    parser.addOption(QCommandLineOption(QStringLiteral("item"),
+                                        i18n(
+                                            "Loads an existing item, or returns without doing anything "
+                                            "when the item is not an event or todo."),
+                                        QStringLiteral("id")));
     parser.process(app);
 
     Akonadi::Item item(-1);
